@@ -90,8 +90,6 @@ static PyObject *_wrap_applet_widget_register_callback(PyObject *self, PyObject
     PyErr_SetString(PyExc_TypeError, "forth argument not a function");
     return NULL;
   }
-  Py_INCREF(func);
-  Py_INCREF(user_data);
   applet_widget_register_callback(APPLET_WIDGET(PyGtk_Get(applet)),
 				  name, menutext, 
 				  PyGnome_applet_callback,
@@ -112,8 +110,6 @@ static PyObject *_wrap_applet_widget_register_stock_callback(PyObject *self, PyO
     PyErr_SetString(PyExc_TypeError, "fifth argument not a function");
     return NULL;
   }
-  Py_INCREF(func);
-  Py_INCREF(user_data);
   applet_widget_register_stock_callback(APPLET_WIDGET(PyGtk_Get(applet)),
 					name, stock_type, menutext, 
 					PyGnome_applet_callback,
