@@ -6,7 +6,7 @@ if not gnome.gnomelib_init_called:
 
 def get_string(path):
 	return _gnome.gnome_config_get_string(path)
-def get_trandlated_string(path):
+def get_translated_string(path):
 	return _gnome.gnome_config_get_translated_string(path)
 def get_int(path):
 	return _gnome.gnome_config_get_int(path)
@@ -18,7 +18,7 @@ def get_vector(path):
 	return _gnome.gnome_config_get_vector(path)
 def set_string(path, val):
 	_gnome.gnome_config_set_string(path, val)
-def set_trandlated_string(path, val):
+def set_translated_string(path, val):
 	_gnome.gnome_config_set_translated_string(path, val)
 def set_int(path, val):
 	_gnome.gnome_config_set_int(path, val)
@@ -38,7 +38,7 @@ def enum_sections(path):
 
 def private_get_string(path):
 	return _gnome.gnome_config_private_get_string(path)
-def private_get_trandlated_string(path):
+def private_get_translated_string(path):
 	return _gnome.gnome_config_private_get_translated_string(path)
 def private_get_int(path):
 	return _gnome.gnome_config_private_get_int(path)
@@ -50,7 +50,7 @@ def private_get_vector(path):
 	return _gnome.gnome_config_private_get_vector(path)
 def private_set_string(path, val):
 	_gnome.gnome_config_private_set_string(path, val)
-def private_set_trandlated_string(path, val):
+def private_set_translated_string(path, val):
 	_gnome.gnome_config_private_set_translated_string(path, val)
 def private_set_int(path, val):
 	_gnome.gnome_config_private_set_int(path, val)
