@@ -1160,7 +1160,7 @@ class GnomeMDIGenericChild(GnomeMDIChild):
 			a = list(args)
 			for i in range(len(args)):
 				if type(args[i]) == _gtk._gtk.GtkObjectType:
-					aa[i] = _obj2inst(args[i])
+					a[i] = _obj2inst(args[i])
 			a = tuple(a)
 			ret = apply(self.func, a)
 			if hasattr(ret, '_o'): ret = ret._o
