@@ -75,6 +75,7 @@ static GnomeUIInfo *list_to_ui_info(PyObject *list, gboolean inc_uibd) {
     inf[0].type = GNOME_APP_UI_BUILDER_DATA;
     inf[0].label = inf[0].hint = NULL;
     inf[0].moreinfo = &PyGnome_UIBuilder;
+    inf[0].user_data = NULL;
     ret = &inf[1];
   } else
     ret = inf = g_new(GnomeUIInfo, len + 1);
@@ -963,7 +964,7 @@ static PyObject *_wrap_gnome_mdi_generic_child_set_menu_creator(PyObject *self,
     PyTuple_SetItem(tmp, 1, data);
     func = tmp;
   }
-  gnome_mdi_generic_child_set_menu_creator_full(GNOME_MDI_GENERIC_CHILD(mdi),
+  gnome_mdi_generic_child_set_menu_creator_full(GNOME_MDI_GENERIC_CHILD(PyGtk_Get (mdi)),
 						NULL,
 						PyGtk_CallbackMarshal,
 						func,
@@ -990,7 +991,7 @@ static PyObject *_wrap_gnome_mdi_generic_child_set_config_func(PyObject *self, P
     PyTuple_SetItem(tmp, 1, data);
     func = tmp;
   }
-  gnome_mdi_generic_child_set_config_func_full(GNOME_MDI_GENERIC_CHILD(mdi),
+  gnome_mdi_generic_child_set_config_func_full(GNOME_MDI_GENERIC_CHILD(PyGtk_Get (mdi)),
 					       NULL,
 					       PyGtk_CallbackMarshal,
 					       func,
@@ -1017,7 +1018,7 @@ static PyObject *_wrap_gnome_mdi_generic_child_set_label_func(PyObject *self, Py
     PyTuple_SetItem(tmp, 1, data);
     func = tmp;
   }
-  gnome_mdi_generic_child_set_label_func_full(GNOME_MDI_GENERIC_CHILD(mdi),
+  gnome_mdi_generic_child_set_label_func_full(GNOME_MDI_GENERIC_CHILD(PyGtk_Get (mdi)),
 					      NULL,
 					      PyGtk_CallbackMarshal,
 					      func,
